@@ -379,7 +379,7 @@ struct _VteTerminalPrivate {
 };
 
 
-VteRowData *_vte_terminal_ensure_cursor(VteTerminal *terminal, gboolean current);
+VteRowData *_vte_terminal_ensure_row(VteTerminal *terminal);
 void _vte_terminal_set_pointer_visible(VteTerminal *terminal, gboolean visible);
 void _vte_invalidate_all(VteTerminal *terminal);
 void _vte_invalidate_cells(VteTerminal *terminal,
